/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, YearViewService, NavigationService } from '@progress/kendo-angular-dateinputs';
import { DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_GRID_BODY_EXPORTS, KENDO_GRID_COLUMN_MENU_DECLARATIONS, KENDO_GRID_DECLARATIONS, KENDO_GRID_EXPORTS, KENDO_GRID_FILTER_MENU, KENDO_GRID_FILTER_ROW, KENDO_GRID_FOOTER_EXPORTS, KENDO_GRID_GROUP_EXPORTS, KENDO_GRID_HEADER_EXPORTS, KENDO_GRID_SHARED } from './directives';
import { TableDirective } from './column-resizing/table.directive';
import { KENDO_PAGER } from '@progress/kendo-angular-pager';
import { KENDO_TOOLBAR } from '@progress/kendo-angular-toolbar';
import * as i0 from "@angular/core";
import * as i1 from "./grouping/group-header-template.directive";
import * as i2 from "./grouping/group-header-column-template.directive";
import * as i3 from "./grouping/group-footer-template.directive";
import * as i4 from "./grouping/group-header.component";
import * as i5 from "./grouping/group-panel.component";
import * as i6 from "./columns/column.component";
import * as i7 from "./columns/column-group.component";
import * as i8 from "./navigation/logical-cell.directive";
import * as i9 from "./navigation/logical-row.directive";
import * as i10 from "./navigation/focusable.directive";
import * as i11 from "./rendering/footer/footer-template.directive";
import * as i12 from "./rendering/common/col-group.component";
import * as i13 from "./layout/resizable.directive";
import * as i14 from "@progress/kendo-angular-common";
import * as i15 from "./rendering/common/field-accessor.pipe";
import * as i16 from "./rendering/details/detail-template.directive";
import * as i17 from "./columns/span-column.component";
import * as i18 from "./rendering/common/loading.component";
import * as i19 from "./rendering/grid-table.directive";
import * as i20 from "./columns/command-column.component";
import * as i21 from "./columns/checkbox-column.component";
import * as i22 from "./selection/selection-checkbox.directive";
import * as i23 from "./rendering/cell-template.directive";
import * as i24 from "./editing/edit-template.directive";
import * as i25 from "./row-reordering/drag-handle-template.directive";
import * as i26 from "./row-reordering/drag-hint-template.directive";
import * as i27 from "./rendering/table-body.component";
import * as i28 from "./rendering/no-records-template.directive";
import * as i29 from "./rendering/cell.component";
import * as i30 from "./editing/edit-command.directive";
import * as i31 from "./editing/cancel-command.directive";
import * as i32 from "./editing/save-command.directive";
import * as i33 from "./editing/remove-command.directive";
import * as i34 from "./editing/add-command.directive";
import * as i35 from "./editing/add-command-tool.directive";
import * as i36 from "./rendering/cell-loading.template.directive";
import * as i37 from "./rendering/loading-template.directive";
import * as i38 from "./columns/reorder-column.component";
import * as i39 from "./rendering/toolbar/tools/sort-command-tool.directive";
import * as i40 from "./rendering/toolbar/tools/filter-command-tool.directive";
import * as i41 from "./rendering/header/header.component";
import * as i42 from "./rendering/header/header-template.directive";
import * as i43 from "./column-resizing/column-handle.directive";
import * as i44 from "./selection/selectall-checkbox.directive";
import * as i45 from "./rendering/footer/footer.component";
import * as i46 from "@progress/kendo-angular-pager";
import * as i47 from "@progress/kendo-angular-toolbar";
import * as i48 from "./filtering/filter-row.component";
import * as i49 from "./filtering/cell/filter-cell.component";
import * as i50 from "./filtering/cell/filter-cell-template.directive";
import * as i51 from "./filtering/cell/string-filter-cell.component";
import * as i52 from "./filtering/cell/numeric-filter-cell.component";
import * as i53 from "./filtering/cell/autocomplete-filter-cell.component";
import * as i54 from "./filtering/cell/boolean-filter-cell.component";
import * as i55 from "./filtering/cell/filter-cell-host.directive";
import * as i56 from "./filtering/cell/filter-cell-wrapper.component";
import * as i57 from "./filtering/cell/date-filter-cell.component";
import * as i58 from "./filtering/cell/filter-cell-operators.component";
import * as i59 from "./filtering/operators/contains-filter-operator.component";
import * as i60 from "./filtering/operators/not-contains-filter-operator.component";
import * as i61 from "./filtering/operators/ends-with-filter-operator.component";
import * as i62 from "./filtering/operators/eq-filter-operator.component";
import * as i63 from "./filtering/operators/is-empty-filter-operator.component";
import * as i64 from "./filtering/operators/is-not-empty-filter-operator.component";
import * as i65 from "./filtering/operators/is-not-null-filter-operator.component";
import * as i66 from "./filtering/operators/isnull-filter-operator.component";
import * as i67 from "./filtering/operators/neq-filter-operator.component";
import * as i68 from "./filtering/operators/starts-with-filter-operator.component";
import * as i69 from "./filtering/operators/gt-filter-operator.component";
import * as i70 from "./filtering/operators/gte-filter-operator.component";
import * as i71 from "./filtering/operators/lt-filter-operator.component";
import * as i72 from "./filtering/operators/lte-filter-operator.component";
import * as i73 from "./filtering/operators/after-filter-operator.component";
import * as i74 from "./filtering/operators/after-eq-filter-operator.component";
import * as i75 from "./filtering/operators/before-eq-filter-operator.component";
import * as i76 from "./filtering/operators/before-filter-operator.component";
import * as i77 from "./filtering/filter-input.directive";
import * as i78 from "./filtering/menu/filter-menu.component";
import * as i79 from "./filtering/menu/filter-menu-container.component";
import * as i80 from "./filtering/menu/filter-menu-input-wrapper.component";
import * as i81 from "./filtering/menu/string-filter-menu-input.component";
import * as i82 from "./filtering/menu/string-filter-menu.component";
import * as i83 from "./filtering/menu/filter-menu-template.directive";
import * as i84 from "./filtering/menu/numeric-filter-menu.component";
import * as i85 from "./filtering/menu/numeric-filter-menu-input.component";
import * as i86 from "./filtering/menu/date-filter-menu-input.component";
import * as i87 from "./filtering/menu/date-filter-menu.component";
import * as i88 from "./filtering/menu/filter-menu-host.directive";
import * as i89 from "./filtering/menu/boolean-filter-menu.component";
import * as i90 from "./filtering/menu/filter-menu-dropdownlist.directive";
import * as i91 from "./filtering/menu/filter-radio-button.directive";
import * as i92 from "./column-menu/column-chooser-item-checked.directive";
import * as i93 from "./column-menu/column-list.component";
import * as i94 from "./column-menu/column-chooser.component";
import * as i95 from "./column-menu/column-chooser-tool.directive";
import * as i96 from "./column-menu/column-menu-chooser.component";
import * as i97 from "./column-menu/column-menu-filter.component";
import * as i98 from "./column-menu/column-menu-item.component";
import * as i99 from "./column-menu/column-menu-item-content-template.directive";
import * as i100 from "./column-menu/column-menu-sort.component";
import * as i101 from "./column-menu/column-menu.component";
import * as i102 from "./column-menu/column-menu-lock.component";
import * as i103 from "./column-menu/column-menu-template.directive";
import * as i104 from "./column-menu/column-menu-container.component";
import * as i105 from "./column-menu/column-menu-item.directive";
import * as i106 from "./column-menu/column-menu-stick.component";
import * as i107 from "./column-menu/column-menu-position.component";
import * as i108 from "./column-menu/column-menu-autosize.component";
import * as i109 from "./column-menu/column-menu-autosize-all.component";
import * as i110 from "./grid.component";
import * as i111 from "./rendering/list.component";
import * as i112 from "./rendering/toolbar/toolbar.component";
import * as i113 from "./localization/localized-messages.directive";
import * as i114 from "./localization/custom-messages.component";
import * as i115 from "./databinding.directive";
import * as i116 from "./rendering/toolbar/toolbar-template.directive";
import * as i117 from "./selection/selection.directive";
import * as i118 from "./editing-directives/template-editing.directive";
import * as i119 from "./editing-directives/reactive-editing.directive";
import * as i120 from "./editing-directives/in-cell-editing.directive";
import * as i121 from "./editing-directives/external-editing.directive";
import * as i122 from "./rendering/details-expand.directive";
import * as i123 from "./rendering/groups-expand.directive";
import * as i124 from "./grouping/group-scroll-binding.directive";
import * as i125 from "./selection/marquee.directive";
import * as i126 from "./rendering/common/spacer.component";
import * as i127 from "./rendering/toolbar/toolbar-focusable.directive";
import * as i128 from "./aggregates/status-bar.component";
import * as i129 from "./aggregates/status-bar-template.directive";
import * as i130 from "./common/clipboard.directive";
import * as i131 from "./editing/form/form.component";
import * as i132 from "./editing/form/dialog-form.component";
import * as i133 from "./editing/form/form-formfield.component";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Grid component.
 *
 * @example
 *
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { GridModule } from '@progress/kendo-angular-grid';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *     declarations: [AppComponent],
 *     imports:      [BrowserModule, GridModule],
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * ```
 */
export class GridModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: GridModule, imports: [i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.RowDragHandleTemplateDirective, i26.RowDragHintTemplateDirective, i27.TableBodyComponent, i28.NoRecordsTemplateDirective, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i35.AddCommandToolbarDirective, i36.CellLoadingTemplateDirective, i37.LoadingTemplateDirective, i38.RowReorderColumnComponent, i39.SortCommandToolbarDirective, i40.FilterCommandToolbarDirective, i41.HeaderComponent, i42.HeaderTemplateDirective, i43.ColumnHandleDirective, i44.SelectAllCheckboxDirective, i45.FooterComponent, i46.CustomMessagesComponent, i46.PagerFocusableDirective, i46.PagerInfoComponent, i46.PagerInputComponent, i46.PagerNextButtonsComponent, i46.PagerNumericButtonsComponent, i46.PagerPageSizesComponent, i46.PagerPrevButtonsComponent, i46.PagerTemplateDirective, i46.PagerComponent, i46.PagerSpacerComponent, i47.ToolBarComponent, i47.ToolbarCustomMessagesComponent, i47.ToolBarButtonComponent, i47.ToolBarButtonGroupComponent, i47.ToolBarDropDownButtonComponent, i47.ToolBarSeparatorComponent, i47.ToolBarSpacerComponent, i47.ToolBarSplitButtonComponent, i47.ToolBarToolComponent, i48.FilterRowComponent, i49.FilterCellComponent, i50.FilterCellTemplateDirective, i51.StringFilterCellComponent, i52.NumericFilterCellComponent, i53.AutoCompleteFilterCellComponent, i54.BooleanFilterCellComponent, i55.FilterCellHostDirective, i56.FilterCellWrapperComponent, i57.DateFilterCellComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i58.FilterCellOperatorsComponent, i59.ContainsFilterOperatorComponent, i60.DoesNotContainFilterOperatorComponent, i61.EndsWithFilterOperatorComponent, i62.EqualFilterOperatorComponent, i63.IsEmptyFilterOperatorComponent, i64.IsNotEmptyFilterOperatorComponent, i65.IsNotNullFilterOperatorComponent, i66.IsNullFilterOperatorComponent, i67.NotEqualFilterOperatorComponent, i68.StartsWithFilterOperatorComponent, i69.GreaterFilterOperatorComponent, i70.GreaterOrEqualToFilterOperatorComponent, i71.LessFilterOperatorComponent, i72.LessOrEqualToFilterOperatorComponent, i73.AfterFilterOperatorComponent, i74.AfterEqFilterOperatorComponent, i75.BeforeEqFilterOperatorComponent, i76.BeforeFilterOperatorComponent, i77.FilterInputDirective, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i58.FilterCellOperatorsComponent, i59.ContainsFilterOperatorComponent, i60.DoesNotContainFilterOperatorComponent, i61.EndsWithFilterOperatorComponent, i62.EqualFilterOperatorComponent, i63.IsEmptyFilterOperatorComponent, i64.IsNotEmptyFilterOperatorComponent, i65.IsNotNullFilterOperatorComponent, i66.IsNullFilterOperatorComponent, i67.NotEqualFilterOperatorComponent, i68.StartsWithFilterOperatorComponent, i69.GreaterFilterOperatorComponent, i70.GreaterOrEqualToFilterOperatorComponent, i71.LessFilterOperatorComponent, i72.LessOrEqualToFilterOperatorComponent, i73.AfterFilterOperatorComponent, i74.AfterEqFilterOperatorComponent, i75.BeforeEqFilterOperatorComponent, i76.BeforeFilterOperatorComponent, i77.FilterInputDirective, i78.FilterMenuComponent, i79.FilterMenuContainerComponent, i80.FilterMenuInputWrapperComponent, i81.StringFilterMenuInputComponent, i82.StringFilterMenuComponent, i83.FilterMenuTemplateDirective, i84.NumericFilterMenuComponent, i85.NumericFilterMenuInputComponent, i86.DateFilterMenuInputComponent, i87.DateFilterMenuComponent, i88.FilterMenuHostDirective, i89.BooleanFilterMenuComponent, i90.FilterMenuDropDownListDirective, i91.BooleanFilterRadioButtonDirective, i92.ColumnMenuChooserItemCheckedDirective, i93.ColumnListComponent, i94.ColumnChooserComponent, i95.ColumnChooserToolbarDirective, i96.ColumnMenuChooserComponent, i97.ColumnMenuFilterComponent, i98.ColumnMenuItemComponent, i99.ColumnMenuItemContentTemplateDirective, i100.ColumnMenuSortComponent, i101.ColumnMenuComponent, i102.ColumnMenuLockComponent, i103.ColumnMenuTemplateDirective, i104.ColumnMenuContainerComponent, i105.ColumnMenuItemDirective, i106.ColumnMenuStickComponent, i107.ColumnMenuPositionComponent, i108.ColumnMenuAutoSizeColumnComponent, i109.ColumnMenuAutoSizeAllColumnsComponent, i110.GridComponent, i111.ListComponent, i112.ToolbarComponent, i113.LocalizedMessagesDirective, i114.CustomMessagesComponent, i115.DataBindingDirective, i116.ToolbarTemplateDirective, i117.SelectionDirective, i118.TemplateEditingDirective, i119.ReactiveEditingDirective, i120.InCellEditingDirective, i121.ExternalEditingDirective, i122.ExpandDetailsDirective, i123.ExpandGroupDirective, i124.GroupBindingDirective, i125.GridMarqueeDirective, i126.GridSpacerComponent, i127.GridToolbarFocusableDirective, i128.StatusBarComponent, i129.StatusBarTemplateDirective, i130.GridClipboardDirective, i131.FormComponent, i132.DialogFormComponent, i133.FormFormFieldComponent, i47.ToolBarComponent, i47.ToolbarCustomMessagesComponent, i47.ToolBarButtonComponent, i47.ToolBarButtonGroupComponent, i47.ToolBarDropDownButtonComponent, i47.ToolBarSeparatorComponent, i47.ToolBarSpacerComponent, i47.ToolBarSplitButtonComponent, i47.ToolBarToolComponent, TableDirective], exports: [i110.GridComponent, i116.ToolbarTemplateDirective, i112.ToolbarComponent, i126.GridSpacerComponent, i129.StatusBarTemplateDirective, i115.DataBindingDirective, i117.SelectionDirective, i114.CustomMessagesComponent, i124.GroupBindingDirective, i118.TemplateEditingDirective, i119.ReactiveEditingDirective, i120.InCellEditingDirective, i121.ExternalEditingDirective, i122.ExpandDetailsDirective, i123.ExpandGroupDirective, i127.GridToolbarFocusableDirective, i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.RowDragHandleTemplateDirective, i26.RowDragHintTemplateDirective, i27.TableBodyComponent, i28.NoRecordsTemplateDirective, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i35.AddCommandToolbarDirective, i36.CellLoadingTemplateDirective, i37.LoadingTemplateDirective, i38.RowReorderColumnComponent, i39.SortCommandToolbarDirective, i40.FilterCommandToolbarDirective, i41.HeaderComponent, i42.HeaderTemplateDirective, i43.ColumnHandleDirective, i44.SelectAllCheckboxDirective, i48.FilterRowComponent, i49.FilterCellComponent, i50.FilterCellTemplateDirective, i51.StringFilterCellComponent, i52.NumericFilterCellComponent, i53.AutoCompleteFilterCellComponent, i54.BooleanFilterCellComponent, i55.FilterCellHostDirective, i56.FilterCellWrapperComponent, i57.DateFilterCellComponent, i58.FilterCellOperatorsComponent, i59.ContainsFilterOperatorComponent, i60.DoesNotContainFilterOperatorComponent, i61.EndsWithFilterOperatorComponent, i62.EqualFilterOperatorComponent, i63.IsEmptyFilterOperatorComponent, i64.IsNotEmptyFilterOperatorComponent, i65.IsNotNullFilterOperatorComponent, i66.IsNullFilterOperatorComponent, i67.NotEqualFilterOperatorComponent, i68.StartsWithFilterOperatorComponent, i69.GreaterFilterOperatorComponent, i70.GreaterOrEqualToFilterOperatorComponent, i71.LessFilterOperatorComponent, i72.LessOrEqualToFilterOperatorComponent, i73.AfterFilterOperatorComponent, i74.AfterEqFilterOperatorComponent, i75.BeforeEqFilterOperatorComponent, i76.BeforeFilterOperatorComponent, i78.FilterMenuComponent, i79.FilterMenuContainerComponent, i80.FilterMenuInputWrapperComponent, i81.StringFilterMenuInputComponent, i82.StringFilterMenuComponent, i83.FilterMenuTemplateDirective, i84.NumericFilterMenuComponent, i85.NumericFilterMenuInputComponent, i86.DateFilterMenuInputComponent, i87.DateFilterMenuComponent, i88.FilterMenuHostDirective, i89.BooleanFilterMenuComponent, i90.FilterMenuDropDownListDirective, i91.BooleanFilterRadioButtonDirective, i94.ColumnChooserComponent, i95.ColumnChooserToolbarDirective, i97.ColumnMenuFilterComponent, i98.ColumnMenuItemComponent, i99.ColumnMenuItemContentTemplateDirective, i100.ColumnMenuSortComponent, i102.ColumnMenuLockComponent, i106.ColumnMenuStickComponent, i107.ColumnMenuPositionComponent, i96.ColumnMenuChooserComponent, i103.ColumnMenuTemplateDirective, i104.ColumnMenuContainerComponent, i105.ColumnMenuItemDirective, i101.ColumnMenuComponent, i108.ColumnMenuAutoSizeColumnComponent, i109.ColumnMenuAutoSizeAllColumnsComponent, i130.GridClipboardDirective, i47.ToolBarComponent, i47.ToolbarCustomMessagesComponent, i47.ToolBarButtonComponent, i47.ToolBarButtonGroupComponent, i47.ToolBarDropDownButtonComponent, i47.ToolBarSeparatorComponent, i47.ToolBarSpacerComponent, i47.ToolBarSplitButtonComponent, i47.ToolBarToolComponent, i46.CustomMessagesComponent, i46.PagerFocusableDirective, i46.PagerInfoComponent, i46.PagerInputComponent, i46.PagerNextButtonsComponent, i46.PagerNumericButtonsComponent, i46.PagerPageSizesComponent, i46.PagerPrevButtonsComponent, i46.PagerTemplateDirective, i46.PagerComponent, i46.PagerSpacerComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, providers: [
            PopupService,
            ResizeBatchService,
            IconsService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService,
            CalendarDOMService,
            CenturyViewService,
            DecadeViewService,
            MonthViewService,
            YearViewService,
            NavigationService
        ], imports: [i4.GroupHeaderComponent, i5.GroupPanelComponent, i27.TableBodyComponent, i29.CellComponent, i30.EditCommandDirective, i31.CancelCommandDirective, i32.SaveCommandDirective, i33.RemoveCommandDirective, i34.AddCommandDirective, i41.HeaderComponent, i46.CustomMessagesComponent, i46.PagerInfoComponent, i46.PagerInputComponent, i46.PagerNextButtonsComponent, i46.PagerNumericButtonsComponent, i46.PagerPageSizesComponent, i46.PagerPrevButtonsComponent, i46.PagerComponent, i46.PagerSpacerComponent, i47.ToolBarComponent, i47.ToolbarCustomMessagesComponent, i47.ToolBarButtonComponent, i47.ToolBarButtonGroupComponent, i47.ToolBarDropDownButtonComponent, i47.ToolBarSeparatorComponent, i47.ToolBarSpacerComponent, i47.ToolBarSplitButtonComponent, i51.StringFilterCellComponent, i52.NumericFilterCellComponent, i53.AutoCompleteFilterCellComponent, i54.BooleanFilterCellComponent, i56.FilterCellWrapperComponent, i57.DateFilterCellComponent, i58.FilterCellOperatorsComponent, i58.FilterCellOperatorsComponent, i78.FilterMenuComponent, i79.FilterMenuContainerComponent, i80.FilterMenuInputWrapperComponent, i81.StringFilterMenuInputComponent, i82.StringFilterMenuComponent, i84.NumericFilterMenuComponent, i85.NumericFilterMenuInputComponent, i86.DateFilterMenuInputComponent, i87.DateFilterMenuComponent, i89.BooleanFilterMenuComponent, i93.ColumnListComponent, i94.ColumnChooserComponent, i96.ColumnMenuChooserComponent, i97.ColumnMenuFilterComponent, i98.ColumnMenuItemComponent, i100.ColumnMenuSortComponent, i101.ColumnMenuComponent, i102.ColumnMenuLockComponent, i106.ColumnMenuStickComponent, i107.ColumnMenuPositionComponent, i108.ColumnMenuAutoSizeColumnComponent, i109.ColumnMenuAutoSizeAllColumnsComponent, i110.GridComponent, i111.ListComponent, i131.FormComponent, i132.DialogFormComponent, i133.FormFormFieldComponent, i47.ToolBarComponent, i47.ToolbarCustomMessagesComponent, i47.ToolBarButtonComponent, i47.ToolBarButtonGroupComponent, i47.ToolBarDropDownButtonComponent, i47.ToolBarSeparatorComponent, i47.ToolBarSpacerComponent, i47.ToolBarSplitButtonComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: GridModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_GRID_EXPORTS, ...KENDO_TOOLBAR, ...KENDO_PAGER],
                    imports: [
                        ...KENDO_GRID_GROUP_EXPORTS,
                        ...KENDO_GRID_SHARED,
                        ...KENDO_GRID_BODY_EXPORTS,
                        ...KENDO_GRID_HEADER_EXPORTS,
                        ...KENDO_GRID_FOOTER_EXPORTS,
                        ...KENDO_PAGER,
                        ...KENDO_TOOLBAR,
                        ...KENDO_GRID_FILTER_ROW,
                        ...KENDO_GRID_FILTER_MENU,
                        ...KENDO_GRID_COLUMN_MENU_DECLARATIONS,
                        ...KENDO_GRID_DECLARATIONS,
                        ...KENDO_TOOLBAR,
                        TableDirective
                    ],
                    providers: [
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        NavigationService
                    ]
                }]
        }] });
