/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, ElementRef, EventEmitter, Output, QueryList, ViewChildren } from '@angular/core';
import { ContextService } from '../../../common/provider.service';
import { NgFor } from '@angular/common';
import { KENDO_BUTTON } from '@progress/kendo-angular-buttons';
import { FilterMenuContainerComponent } from '../../../filtering/menu/filter-menu-container.component';
import { FilterService } from '../../../filtering/filter.service';
import { ColumnMenuItemComponent } from '../../../column-menu/column-menu-item.component';
import { ColumnMenuItemContentTemplateDirective } from '../../../column-menu/column-menu-item-content-template.directive';
import { ColumnInfoService } from '../../../common/column-info.service';
import { cloneFilters } from '../../../common/filter-descriptor-differ';
import * as i0 from "@angular/core";
import * as i1 from "../../../filtering/filter.service";
import * as i2 from "../../../common/provider.service";
import * as i3 from "../../../common/column-info.service";
/**
 * @hidden
 */
export class FilterToolbarToolComponent {
    element;
    filterService;
    ctx;
    columnInfoService;
    filterItems;
    menuItems;
    filterContainers;
    close = new EventEmitter();
    get hostStyles() {
        return {
            'maxHeight': '400px',
            'overflowX': 'hidden',
            'overflowY': 'auto'
        };
    }
    columnMenuService;
    columns;
    filter;
    subscriptions;
    constructor(element, filterService, ctx, columnInfoService) {
        this.element = element;
        this.filterService = filterService;
        this.ctx = ctx;
        this.columnInfoService = columnInfoService;
    }
    ngOnInit() {
        this.columns = this.columnInfoService.leafNamedColumns.filter(column => column?.filterable);
        this.filter = this.ctx.grid.filter;
        this.subscriptions = this.filterService.changes.subscribe(filter => {
            this.filter = cloneFilters(filter);
        });
    }
    ngAfterViewInit() {
        this.filterItems?.get(0)?.nativeElement.focus();
    }
    ngOnDestroy() {
        if (this.subscriptions) {
            this.subscriptions.unsubscribe();
        }
    }
    getColumnComponent(column) {
        return column;
    }
    handleClose(filterItem) {
        filterItem.expanded = false;
        filterItem.contentState = 'collapsed';
    }
    toggleItem(event, index) {
        const menuItem = this.menuItems.get(index);
        if (!menuItem || event.target.closest('.k-filter-menu-container')) {
            return;
        }
        if (menuItem.expanded) {
            this.filterContainers.get(index).isExpanded = false;
            menuItem.expanded = false;
            menuItem.contentState = 'collapsed';
        }
        else {
            this.filterContainers.get(index).isExpanded = true;
            menuItem.expanded = true;
            menuItem.contentState = 'expanded';
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterToolbarToolComponent, deps: [{ token: i0.ElementRef }, { token: i1.FilterService }, { token: i2.ContextService }, { token: i3.ColumnInfoService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: FilterToolbarToolComponent, isStandalone: true, selector: "kendo-filter-toolbar-tool", outputs: { close: "close" }, viewQueries: [{ propertyName: "filterItems", predicate: ["filterItem"], descendants: true, read: ElementRef }, { propertyName: "menuItems", predicate: ["filterItem"], descendants: true }, { propertyName: "filterContainers", predicate: ["filterContainer"], descendants: true }], ngImport: i0, template: `
        <div [style]="hostStyles">
            <kendo-grid-columnmenu-item *ngFor="let column of columns; let i = index"
                class="k-columnmenu-item-wrapper" #filterItem
                role="button"
                tabindex="0"
                [text]="column.title || getColumnComponent(column).field"
                (keydown.enter)="toggleItem($event, i)"
                [expanded]="false">
                <ng-template kendoGridColumnMenuItemContentTemplate>
                    <kendo-grid-filter-menu-container
                        #filterContainer
                        (keydown.shift.tab)="$event.stopImmediatePropagation()"
                        [column]="getColumnComponent(column)"
                        [filter]="filter"
                        [isExpanded]="false"
                        (close)="handleClose(filterItem)">
                    </kendo-grid-filter-menu-container>
                </ng-template>
            </kendo-grid-columnmenu-item>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: FilterMenuContainerComponent, selector: "kendo-grid-filter-menu-container", inputs: ["column", "isLast", "isExpanded", "menuTabbingService", "filter", "actionsClass"], outputs: ["close"] }, { kind: "component", type: ColumnMenuItemComponent, selector: "kendo-grid-columnmenu-item", inputs: ["icon", "svgIcon", "text", "selected", "disabled", "expanded", "service"], outputs: ["itemClick", "expand", "collapse"] }, { kind: "directive", type: ColumnMenuItemContentTemplateDirective, selector: "[kendoGridColumnMenuItemContentTemplate]" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterToolbarToolComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-filter-toolbar-tool',
                    template: `
        <div [style]="hostStyles">
            <kendo-grid-columnmenu-item *ngFor="let column of columns; let i = index"
                class="k-columnmenu-item-wrapper" #filterItem
                role="button"
                tabindex="0"
                [text]="column.title || getColumnComponent(column).field"
                (keydown.enter)="toggleItem($event, i)"
                [expanded]="false">
                <ng-template kendoGridColumnMenuItemContentTemplate>
                    <kendo-grid-filter-menu-container
                        #filterContainer
                        (keydown.shift.tab)="$event.stopImmediatePropagation()"
                        [column]="getColumnComponent(column)"
                        [filter]="filter"
                        [isExpanded]="false"
                        (close)="handleClose(filterItem)">
                    </kendo-grid-filter-menu-container>
                </ng-template>
            </kendo-grid-columnmenu-item>
        </div>
    `,
                    standalone: true,
                    imports: [NgFor, KENDO_BUTTON, FilterMenuContainerComponent, ColumnMenuItemComponent, ColumnMenuItemContentTemplateDirective]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i1.FilterService }, { type: i2.ContextService }, { type: i3.ColumnInfoService }]; }, propDecorators: { filterItems: [{
                type: ViewChildren,
                args: ['filterItem', { read: ElementRef }]
            }], menuItems: [{
                type: ViewChildren,
                args: ['filterItem']
            }], filterContainers: [{
                type: ViewChildren,
                args: ['filterContainer']
            }], close: [{
                type: Output
            }] } });
